Struct big_strats_pkg::grid::msgs::RemoveGridMsg
source · pub struct RemoveGridMsg {
pub id: u64,
}Fields
id: u64Trait Implementations
sourceimpl Clone for RemoveGridMsg
impl Clone for RemoveGridMsg
sourcefn clone(&self) -> RemoveGridMsg
fn clone(&self) -> RemoveGridMsg
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RemoveGridMsg
impl Debug for RemoveGridMsg
sourceimpl<'de> Deserialize<'de> for RemoveGridMsg
impl<'de> Deserialize<'de> for RemoveGridMsg
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for RemoveGridMsg
impl JsonSchema for RemoveGridMsg
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moresourceimpl PartialEq for RemoveGridMsg
impl PartialEq for RemoveGridMsg
sourcefn eq(&self, other: &RemoveGridMsg) -> bool
fn eq(&self, other: &RemoveGridMsg) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for RemoveGridMsg
impl Serialize for RemoveGridMsg
impl StructuralPartialEq for RemoveGridMsg